@@ -18,6 +18,11 @@ if sys.version_info < (2, 6):
     next = lambda gen: gen.next()
 
 
+env_bin_dir = 'bin'
+if sys.platform == 'win32':
+    env_bin_dir = 'Scripts'
+
+
 class UserError(Exception):
     pass
 
@@ -45,12 +50,13 @@ def _dirmatch(path, matchwith):
 
 def _virtualenv_sys(venv_path):
     "obtain version and path info from a virtualenv."
-    executable = os.path.join(venv_path, 'bin', 'python')
-    p = subprocess.Popen(['python',
+    executable = os.path.join(venv_path, env_bin_dir, 'python')
+    # Must use "executable" as the first argument rather than as the
+    # keyword argument "executable" to get correct value from sys.path
+    p = subprocess.Popen([executable,
         '-c', 'import sys;'
               'print (sys.version[:3]);'
               'print ("\\n".join(sys.path));'],
-        executable=executable,
         env={},
         stdout=subprocess.PIPE)
     stdout, err = p.communicate()
@@ -65,9 +71,12 @@ def clone_virtualenv(src_dir, dst_dir):
     if os.path.exists(dst_dir):
         raise UserError('dest dir %r exists' % dst_dir)
     #sys_path = _virtualenv_syspath(src_dir)
+    logger.info('cloning virtualenv \'%s\' => \'%s\'...' %
+            (src_dir, dst_dir))
     shutil.copytree(src_dir, dst_dir, symlinks=True,
             ignore=shutil.ignore_patterns('*.pyc'))
     version, sys_path = _virtualenv_sys(dst_dir)
+    logger.info('fixing scripts in bin...')
     fixup_scripts(src_dir, dst_dir, version)
 
     has_old = lambda s: any(i for i in s if _dirmatch(i, src_dir))
@@ -75,13 +84,15 @@ def clone_virtualenv(src_dir, dst_dir):
     if has_old(sys_path):
         # only need to fix stuff in sys.path if we have old
         # paths in the sys.path of new python env. right?
+        logger.info('fixing paths in sys.path...')
         fixup_syspath_items(sys_path, src_dir, dst_dir)
-    remaining = has_old(_virtualenv_sys(dst_dir)[1])
-    assert not remaining, _virtualenv_sys(dst_dir)
+    v_sys = _virtualenv_sys(dst_dir)
+    remaining = has_old(v_sys[1])
+    assert not remaining, v_sys
 
 
 def fixup_scripts(old_dir, new_dir, version, rewrite_env_python=False):
-    bin_dir = os.path.join(new_dir, 'bin')
+    bin_dir = os.path.join(new_dir, env_bin_dir)
     root, dirs, files = next(os.walk(bin_dir))
     pybinre = re.compile('pythonw?([0-9]+(\.[0-9]+(\.[0-9]+)?)?)?$')
     for file_ in files:
@@ -245,16 +256,23 @@ def fixup_egglink_file(filename, old_dir, new_dir):
 
 
 def main():
-    parser = optparse.OptionParser("usage: %prog /path/to/existing/venv"
-        " /path/to/cloned/venv")
+    parser = optparse.OptionParser("usage: %prog [options]"
+        " /path/to/existing/venv /path/to/cloned/venv")
+    parser.add_option('-v',
+            action="count",
+            dest='verbose',
+            default=False,
+            help='verbosity')
     options, args = parser.parse_args()
     try:
-        old_dir, new_dir = sys.argv[1:]
+        old_dir, new_dir = args
     except ValueError:
         parser.error("not enough arguments given.")
     old_dir = os.path.normpath(os.path.abspath(old_dir))
     new_dir = os.path.normpath(os.path.abspath(new_dir))
-    logging.basicConfig(level=logging.WARNING)
+    loglevel = (logging.WARNING, logging.INFO, logging.DEBUG)[min(2,
+            options.verbose)]
+    logging.basicConfig(level=loglevel, format='%(message)s')
     try:
         clone_virtualenv(old_dir, new_dir)
     except UserError:
